Struct pallet_transaction_payment_rpc_runtime_api::RuntimeDispatchInfo [−][src]
pub struct RuntimeDispatchInfo<Balance> {
pub weight: u64,
pub class: DispatchClass,
pub partial_fee: Balance,
}Expand description
Information related to a dispatchable’s class, weight, and fee that can be queried from the runtime.
Fields
weight: u64Weight of this dispatch.
class: DispatchClassClass of this dispatch.
partial_fee: BalanceThe inclusion fee of this dispatch.
This does not include a tip or anything else that
depends on the signature (i.e. depends on a SignedExtension).